@@ -60,6 +60,9 @@ public class ConfigService {
     }
 
     public ConfigService setConfigPath(String configPath) {
+        if (StringUtils.isNotBlank(configPath) && !configPath.endsWith(File.separator)) {
+            configPath = configPath + File.separator;
+        }
         this.configPath = configPath;
         return this;
     }
@@ -128,7 +131,7 @@ public class ConfigService {
         } else {
             filePath = path.startsWith(FILE_PATH_PREFIX) ? path.substring(FILE_PATH_PREFIX.length()) : this.configPath + path;
         }
-
+        filePath = normalizeFilePath(filePath);
         if (filePath.contains(".jar")) {
             try (final InputStream inputStream = getClass().getResourceAsStream(Objects.requireNonNull(resourceUrl))) {
                 if (inputStream == null) {
@@ -149,6 +152,15 @@ public class ConfigService {
         return (T) object;
     }
 
+    private String normalizeFilePath(String filePath) {
+        if (System.getProperty("os.name").toLowerCase().contains("win")) {
+            if (filePath.startsWith("/")) {
+                filePath = filePath.substring(1);
+            }
+        }
+        return filePath;
+    }
+
     private void populateConfig(Object object, Class<?> clazz, Config config)
         throws NoSuchFieldException, IOException, IllegalAccessException {
         ConfigInfo configInfo = new ConfigInfo();
