@@ -19,7 +19,7 @@ package org.apache.eventmesh.common.protocol.http.header.client;
 
 import java.util.HashMap;
 
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 
 public class UnSubscribeRequestHeaderTest extends AbstractRequestHeaderTest {
 
