@@ -17,9 +17,8 @@
 
 package org.apache.eventmesh.connector.jdbc.connection;
 
-import org.apache.eventmesh.common.utils.LogUtils;
+import org.apache.eventmesh.common.config.connector.rdb.jdbc.JdbcConfig;
 import org.apache.eventmesh.connector.jdbc.JdbcDriverMetaData;
-import org.apache.eventmesh.connector.jdbc.config.JdbcConfig;
 
 import org.apache.commons.lang3.StringUtils;
 
@@ -33,6 +32,7 @@ import java.sql.Statement;
 
 import javax.annotation.concurrent.ThreadSafe;
 
+import lombok.Getter;
 import lombok.extern.slf4j.Slf4j;
 
 /**
@@ -46,6 +46,7 @@ public class JdbcConnection implements AutoCloseable {
 
     private static final String STATEMENT_DELIMITER = ";";
 
+    @Getter
     private final JdbcConfig jdbcConfig;
 
     private volatile Connection connection;
@@ -89,15 +90,6 @@ public class JdbcConnection implements AutoCloseable {
         }
     }
 
-    /**
-     * Retrieves the JDBC configuration.
-     *
-     * @return The JDBC configuration.
-     */
-    public JdbcConfig getJdbcConfig() {
-        return jdbcConfig;
-    }
-
     /**
      * Sets the auto-commit mode for the connection.
      *
@@ -182,7 +174,7 @@ public class JdbcConnection implements AutoCloseable {
         return execute(statement -> {
             for (String sqlStatement : sqlStatements) {
                 if (sqlStatement != null) {
-                    LogUtils.debug(log, "Executing '{}'", sqlStatement);
+                    log.debug("Executing '{}'", sqlStatement);
                     statement.execute(sqlStatement);
                 }
             }
@@ -220,11 +212,10 @@ public class JdbcConnection implements AutoCloseable {
 
         try (Statement statement = conn.createStatement()) {
             for (String sqlStatement : sqlStatements) {
-                LogUtils.debug(log, "Executing sql statement: {}", sqlStatement);
+                log.debug("Executing sql statement: {}", sqlStatement);
                 statement.execute(sqlStatement);
             }
         }
-
         return this;
     }
 
@@ -293,7 +284,7 @@ public class JdbcConnection implements AutoCloseable {
     public JdbcConnection query(String sql, StatementFactory statementFactory, JdbcResultSetConsumer resultConsumer) throws SQLException {
         Connection conn = connection();
         try (Statement statement = statementFactory.createStatement(conn)) {
-            LogUtils.debug(log, "Query sql '{}'", sql);
+            log.debug("Query sql '{}'", sql);
             try (ResultSet resultSet = statement.executeQuery(sql)) {
                 if (resultConsumer != null) {
                     resultConsumer.accept(resultSet);
@@ -331,7 +322,7 @@ public class JdbcConnection implements AutoCloseable {
     public <T> T query(String sql, StatementFactory statementFactory, ResultSetMapper<T> resultSetMapper) throws SQLException {
         Connection conn = connection();
         try (Statement statement = statementFactory.createStatement(conn)) {
-            LogUtils.debug(log, "Query sql '{}'", sql);
+            log.debug("Query sql '{}'", sql);
             try (ResultSet resultSet = statement.executeQuery(sql)) {
                 if (resultSetMapper != null) {
                     return resultSetMapper.map(resultSet);
@@ -374,7 +365,7 @@ public class JdbcConnection implements AutoCloseable {
 
         Connection conn = connection();
         try (PreparedStatement preparedStatement = preparedStatementFactory.createPreparedStatement(conn, sql)) {
-            LogUtils.debug(log, "Query sql '{}'", sql);
+            log.debug("Query sql '{}'", sql);
             if (preparedParameters != null) {
                 for (int index = 0; index < preparedParameters.length; ++index) {
                     final PreparedParameter preparedParameter = preparedParameters[index];
@@ -427,7 +418,7 @@ public class JdbcConnection implements AutoCloseable {
 
         Connection conn = connection();
         try (PreparedStatement preparedStatement = preparedStatementFactory.createPreparedStatement(conn, sql)) {
-            LogUtils.debug(log, "Query sql '{}'", sql);
+            log.debug("Query sql '{}'", sql);
             if (preparedParameters != null) {
                 for (int index = 0; index < preparedParameters.length; ++index) {
                     final PreparedParameter preparedParameter = preparedParameters[index];
@@ -568,9 +559,9 @@ public class JdbcConnection implements AutoCloseable {
             } else {
                 url = urlWithPlaceholder;
             }
-            LogUtils.debug(log, "URL: {}", url);
+            log.debug("URL: {}", url);
             Connection connection = DriverManager.getConnection(url, config.asProperties());
-            LogUtils.debug(log, "User [{}] Connected to {}", config.getUser(), url);
+            log.debug("User [{}] Connected to {}", config.getUser(), url);
             return connection;
         };
     }
