@@ -17,6 +17,8 @@
 
 package org.apache.eventmesh.connector.jdbc.event;
 
+import org.apache.commons.lang3.StringUtils;
+
 public enum SchemaChangeEventType {
 
     DATABASE_CREATE("D", "C"),
@@ -41,4 +43,14 @@ public enum SchemaChangeEventType {
     public String ofOperationType() {
         return this.operationType;
     }
+
+    public static SchemaChangeEventType ofSchemaChangeEventType(String type, String operationType) {
+        SchemaChangeEventType[] types = values();
+        for (SchemaChangeEventType eventType : types) {
+            if (StringUtils.equalsIgnoreCase(eventType.type, type) && StringUtils.equalsIgnoreCase(eventType.operationType, operationType)) {
+                return eventType;
+            }
+        }
+        return null;
+    }
 }
