@@ -18,21 +18,24 @@
 package org.apache.eventmesh.connector.jdbc.source.dialect.cdc.mysql;
 
 import org.apache.eventmesh.common.EventMeshThreadFactory;
-import org.apache.eventmesh.common.utils.LogUtils;
+import org.apache.eventmesh.common.config.connector.Config;
+import org.apache.eventmesh.common.config.connector.rdb.jdbc.JdbcConfig;
+import org.apache.eventmesh.common.config.connector.rdb.jdbc.JdbcSourceConfig;
+import org.apache.eventmesh.common.config.connector.rdb.jdbc.MysqlConfig;
+import org.apache.eventmesh.connector.jdbc.CatalogChanges;
 import org.apache.eventmesh.connector.jdbc.DataChanges;
 import org.apache.eventmesh.connector.jdbc.DataChanges.Builder;
 import org.apache.eventmesh.connector.jdbc.Field;
 import org.apache.eventmesh.connector.jdbc.Payload;
 import org.apache.eventmesh.connector.jdbc.Schema;
-import org.apache.eventmesh.connector.jdbc.config.JdbcConfig;
 import org.apache.eventmesh.connector.jdbc.connection.mysql.MysqlJdbcConnection;
+import org.apache.eventmesh.connector.jdbc.dialect.mysql.MysqlDatabaseDialect;
 import org.apache.eventmesh.connector.jdbc.event.DeleteDataEvent;
 import org.apache.eventmesh.connector.jdbc.event.EventConsumer;
 import org.apache.eventmesh.connector.jdbc.event.GeneralDataChangeEvent;
 import org.apache.eventmesh.connector.jdbc.event.InsertDataEvent;
+import org.apache.eventmesh.connector.jdbc.event.SchemaChangeEventType;
 import org.apache.eventmesh.connector.jdbc.event.UpdateDataEvent;
-import org.apache.eventmesh.connector.jdbc.source.config.JdbcSourceConfig;
-import org.apache.eventmesh.connector.jdbc.source.config.MysqlConfig;
 import org.apache.eventmesh.connector.jdbc.source.dialect.antlr4.mysql.MysqlAntlr4DdlParser;
 import org.apache.eventmesh.connector.jdbc.source.dialect.cdc.AbstractCdcEngine;
 import org.apache.eventmesh.connector.jdbc.source.dialect.cdc.mysql.RowDeserializers.DeleteRowsEventMeshDeserializer;
@@ -41,14 +44,14 @@ import org.apache.eventmesh.connector.jdbc.source.dialect.cdc.mysql.RowDeseriali
 import org.apache.eventmesh.connector.jdbc.source.dialect.mysql.EventDataDeserializationExceptionData;
 import org.apache.eventmesh.connector.jdbc.source.dialect.mysql.EventMeshGtidSet;
 import org.apache.eventmesh.connector.jdbc.source.dialect.mysql.MysqlConstants;
-import org.apache.eventmesh.connector.jdbc.source.dialect.mysql.MysqlDatabaseDialect;
 import org.apache.eventmesh.connector.jdbc.source.dialect.mysql.MysqlJdbcContext;
 import org.apache.eventmesh.connector.jdbc.source.dialect.mysql.MysqlSourceMateData;
 import org.apache.eventmesh.connector.jdbc.table.catalog.Column;
+import org.apache.eventmesh.connector.jdbc.table.catalog.DefaultValueConvertor;
 import org.apache.eventmesh.connector.jdbc.table.catalog.TableId;
 import org.apache.eventmesh.connector.jdbc.table.catalog.TableSchema;
+import org.apache.eventmesh.connector.jdbc.table.catalog.mysql.MysqlDefaultValueConvertorImpl;
 import org.apache.eventmesh.connector.jdbc.table.type.Pair;
-import org.apache.eventmesh.openconnect.api.config.Config;
 
 import org.apache.commons.collections4.CollectionUtils;
 import org.apache.commons.lang3.StringUtils;
@@ -114,6 +117,8 @@ public class MysqlCdcEngine extends AbstractCdcEngine<MysqlAntlr4DdlParser, Mysq
 
     private com.github.shyiko.mysql.binlog.GtidSet localGtidSet;
 
+    private DefaultValueConvertor defaultValueConvertor = new MysqlDefaultValueConvertorImpl();
+
     public MysqlCdcEngine(Config config, MysqlDatabaseDialect databaseDialect) {
         super((JdbcSourceConfig) config, databaseDialect);
         this.ddlParser = new MysqlAntlr4DdlParser(false, false, getHandledTables(), (JdbcSourceConfig) config);
@@ -149,9 +154,7 @@ public class MysqlCdcEngine extends AbstractCdcEngine<MysqlAntlr4DdlParser, Mysq
                 try {
                     // Delegate to the superclass
                     Event event = super.nextEvent(inputStream);
-                    if (log.isDebugEnabled()) {
-                        log.debug("MYSQL Binlog---EventType={}, EventData={}", event.getHeader().getEventType(), event);
-                    }
+                    log.debug("MYSQL Binlog---EventType={}, EventData={}", event.getHeader().getEventType(), event);
                     // We have to record the most recent TableMapEventData for each table number for our custom deserializers
                     if (event.getHeader().getEventType() == EventType.TABLE_MAP) {
                         TableMapEventData tableMapEvent = event.getData();
@@ -286,7 +289,7 @@ public class MysqlCdcEngine extends AbstractCdcEngine<MysqlAntlr4DdlParser, Mysq
      */
     private void eventMeshMysqlEventListener(Event event, MysqlJdbcContext context) {
 
-        if (null == event) {
+        if (event == null) {
             return;
         }
         final EventHeader eventHeader = event.getHeader();
@@ -363,7 +366,7 @@ public class MysqlCdcEngine extends AbstractCdcEngine<MysqlAntlr4DdlParser, Mysq
             Event event = null;
             try {
                 event = eventQueue.poll(5, TimeUnit.SECONDS);
-                if (null == event) {
+                if (event == null) {
                     continue;
                 }
                 eventHandlers.getOrDefault(event.getHeader().getEventType(), ignore -> ignoreEvent(context, ignore)).accept(event);
@@ -389,7 +392,7 @@ public class MysqlCdcEngine extends AbstractCdcEngine<MysqlAntlr4DdlParser, Mysq
             EventMeshGtidSet purgedServerEventMeshGtidSet = new EventMeshGtidSet(purgedServerGtid);
 
             EventMeshGtidSet filteredEventMeshGtidSet = filterGtidSet(context, executedEventMeshGtidSet, purgedServerEventMeshGtidSet);
-            if (null != filteredEventMeshGtidSet) {
+            if (filteredEventMeshGtidSet != null) {
                 client.setGtidSet(filteredEventMeshGtidSet.toString());
                 this.context.completedGtidSet(filteredEventMeshGtidSet.toString());
                 localGtidSet = new com.github.shyiko.mysql.binlog.GtidSet(filteredEventMeshGtidSet.toString());
@@ -424,7 +427,7 @@ public class MysqlCdcEngine extends AbstractCdcEngine<MysqlAntlr4DdlParser, Mysq
      * @param event   the event to be handled
      */
     protected void handleHeartbeatEvent(MysqlJdbcContext context, Event event) {
-        LogUtils.debug(log, "Replication client handle {}", event.getHeader().getEventType());
+        log.debug("Replication client handle {}", event.getHeader().getEventType());
     }
 
     /**
@@ -506,12 +509,13 @@ public class MysqlCdcEngine extends AbstractCdcEngine<MysqlAntlr4DdlParser, Mysq
         }
         String sqlBegin = sql.substring(0, 6).toUpperCase();
         if (StringUtils.startsWithAny(sqlBegin, "INSERT", "UPDATE", "DELETE")) {
-            LogUtils.warn(log, "Received DML '[SQL={}]' for processing, binlog probably contains events generated with statement", sql);
+            log.warn("Received DML '[SQL={}]' for processing, binlog probably contains events generated with statement", sql);
             return;
         }
 
         // set current parse database to Ddl parser
         ddlParser.setCurrentDatabase(queryEventData.getDatabase());
+        ddlParser.setCatalogTableSet(context.getCatalogTableSet());
         ddlParser.parse(sql, this::handleDdlEvent);
     }
 
@@ -519,6 +523,17 @@ public class MysqlCdcEngine extends AbstractCdcEngine<MysqlAntlr4DdlParser, Mysq
         if (event == null) {
             return;
         }
+        // handle default value expression
+        if (event.getJdbcConnectData().isSchemaChanges()) {
+            CatalogChanges catalogChanges = event.getJdbcConnectData().getPayload().getCatalogChanges();
+            SchemaChangeEventType schemaChangeEventType = SchemaChangeEventType.ofSchemaChangeEventType(catalogChanges.getType(),
+                catalogChanges.getOperationType());
+            if (SchemaChangeEventType.TABLE_CREATE == schemaChangeEventType || SchemaChangeEventType.TABLE_ALERT == schemaChangeEventType) {
+                catalogChanges.getColumns().forEach(column -> {
+                    column.setDefaultValue(defaultValueConvertor.parseDefaultValue(column, column.getDefaultValueExpression()));
+                });
+            }
+        }
         event.getJdbcConnectData().getPayload().ofSourceMateData().setSnapshot(false);
         consumers.stream().forEach(consumer -> consumer.accept(event));
     }
@@ -586,7 +601,7 @@ public class MysqlCdcEngine extends AbstractCdcEngine<MysqlAntlr4DdlParser, Mysq
         return sourceMateData;
     }
 
-    private enum CdcDmlType {
+    public enum CdcDmlType {
         INSERT,
         UPDATE,
         DELETE
@@ -609,23 +624,28 @@ public class MysqlCdcEngine extends AbstractCdcEngine<MysqlAntlr4DdlParser, Mysq
         List<Pair<Pair<Serializable[], BitSet>, Pair<Serializable[], BitSet>>> rows, CdcDmlType type) {
 
         TableSchema tableSchema = context.getCatalogTableSet().getTableSchema(tableId);
-        Map<Integer, ? extends Column> orderColumnMap = tableSchema.getOrderColumnMap();
-        List<? extends Column> columns = tableSchema.getColumns();
+        Map<Integer, ? extends Column<?>> orderColumnMap = tableSchema.getOrderColumnMap();
+        List<? extends Column<?>> columns = tableSchema.getColumns();
         List<Field> fields = null;
         Builder builder = DataChanges.newBuilder();
         if (CollectionUtils.isNotEmpty(columns)) {
             fields = columns.stream()
-                .map(col -> new Field(col.getDataType().getName(), col.isNotNull(), col.getName(), tableId.toString()))
-                .collect(Collectors.toList());
+                .map(col -> {
+                    Column<?> rebuild = Column.newBuilder().withName(col.getName()).withDataType(col.getDataType()).withJdbcType(col.getJdbcType())
+                        .withNativeType(col.getNativeType()).withOrder(col.getOrder()).build();
+                    return new Field(rebuild, col.isNotNull(), col.getName(), tableId.toString());
+                }).collect(Collectors.toList());
         }
         int columnsSize = orderColumnMap.size();
         for (Pair<Pair<Serializable[], BitSet>, Pair<Serializable[], BitSet>> pair : rows) {
             GeneralDataChangeEvent dataEvent = buildEvent(type, tableId);
-            Payload payload = dataEvent.getJdbcConnectData().getPayload();
+            builder.withType(dataEvent.getDataChangeEventType().ofCode());
             Schema schema = new Schema();
+            // set primary key
+            schema.addKeys(tableSchema.getPrimaryKey().getColumnNames());
             Pair<Serializable[], BitSet> beforePair = Optional.ofNullable(pair.getLeft()).orElse(new Pair<>());
             Serializable[] beforeRows = beforePair.getLeft();
-            if (null != beforeRows && beforeRows.length != 0) {
+            if (beforeRows != null && beforeRows.length != 0) {
                 BitSet includedColumns = beforePair.getRight();
                 Map<String, Object> beforeValues = new HashMap<>(beforeRows.length);
                 for (int index = 0; index < columnsSize; ++index) {
@@ -636,14 +656,14 @@ public class MysqlCdcEngine extends AbstractCdcEngine<MysqlAntlr4DdlParser, Mysq
                     beforeValues.put(orderColumnMap.get(index + 1).getName(), beforeRows[index]);
                 }
                 builder.withBefore(beforeValues);
-                Field beforeField = new Field().withField(Payload.BEFORE_FIELD).withType("field").withName("payload.before").withRequired(false);
+                Field beforeField = new Field().withField(Payload.BEFORE_FIELD).withName(Payload.PAYLOAD_BEFORE).withRequired(false);
                 beforeField.withRequired(true).withFields(fields);
                 schema.add(beforeField);
             }
 
             Pair<Serializable[], BitSet> afterPair = Optional.ofNullable(pair.getRight()).orElse(new Pair<>());
             Serializable[] afterRows = afterPair.getLeft();
-            if (null != afterRows && afterRows.length != 0) {
+            if (afterRows != null && afterRows.length != 0) {
                 BitSet includedColumns = afterPair.getRight();
                 Map<String, Object> afterValues = new HashMap<>(afterRows.length);
                 for (int index = 0; index < columnsSize; ++index) {
@@ -653,15 +673,15 @@ public class MysqlCdcEngine extends AbstractCdcEngine<MysqlAntlr4DdlParser, Mysq
                     }
                     afterValues.put(orderColumnMap.get(index + 1).getName(), afterRows[index]);
                 }
-                builder.withBefore(afterValues);
-                Field afterField = new Field().withField(Payload.AFTER_FIELD).withType("field").withName("payload.after").withRequired(false);
+                builder.withAfter(afterValues);
+                Field afterField = new Field().withField(Payload.AFTER_FIELD).withName(Payload.PAYLOAD_AFTER).withRequired(false);
                 afterField.withRequired(true).withFields(fields);
                 schema.add(afterField);
             }
+            Payload payload = dataEvent.getJdbcConnectData().getPayload();
             payload.withSource(sourceMateData).withDataChanges(builder.build());
             dataEvent.getJdbcConnectData().setSchema(schema);
             consumers.stream().forEach(consumer -> consumer.accept(dataEvent));
-
         }
     }
 
@@ -732,7 +752,7 @@ public class MysqlCdcEngine extends AbstractCdcEngine<MysqlAntlr4DdlParser, Mysq
     protected void handleGtidEvent(MysqlJdbcContext context, Event event) {
         GtidEventData gtidEvent = unwrapData(event);
         String gtid = gtidEvent.getMySqlGtid().toString();
-        LogUtils.debug(log, "Received GTID event: {}", gtid);
+        log.debug("Received GTID event: {}", gtid);
         localGtidSet.add(gtid);
         context.beginGtid(gtid);
     }
