@@ -17,8 +17,9 @@
 
 package org.apache.eventmesh.connector.rocketmq.sink.connector;
 
-import org.apache.eventmesh.connector.rocketmq.sink.config.RocketMQSinkConfig;
-import org.apache.eventmesh.openconnect.api.config.Config;
+import org.apache.eventmesh.common.config.connector.Config;
+import org.apache.eventmesh.common.config.connector.mq.rocketmq.RocketMQSinkConfig;
+import org.apache.eventmesh.openconnect.api.ConnectorCreateService;
 import org.apache.eventmesh.openconnect.api.connector.ConnectorContext;
 import org.apache.eventmesh.openconnect.api.connector.SinkConnectorContext;
 import org.apache.eventmesh.openconnect.api.sink.Sink;
@@ -34,7 +35,7 @@ import java.util.List;
 import lombok.extern.slf4j.Slf4j;
 
 @Slf4j
-public class RocketMQSinkConnector implements Sink {
+public class RocketMQSinkConnector implements Sink, ConnectorCreateService<Sink> {
 
     private RocketMQSinkConfig sinkConfig;
 
@@ -77,6 +78,11 @@ public class RocketMQSinkConnector implements Sink {
         return this.sinkConfig.getConnectorConfig().getConnectorName();
     }
 
+    @Override
+    public void onException(ConnectRecord record) {
+
+    }
+
     @Override
     public void stop() {
         producer.shutdown();
@@ -108,4 +114,9 @@ public class RocketMQSinkConnector implements Sink {
         }
         return message;
     }
+
+    @Override
+    public Sink create() {
+        return new RocketMQSinkConnector();
+    }
 }
