@@ -24,7 +24,6 @@ import org.apache.eventmesh.common.enums.EventMeshProtocolType;
 import org.apache.eventmesh.common.protocol.SubscriptionItem;
 import org.apache.eventmesh.common.protocol.SubscriptionMode;
 import org.apache.eventmesh.common.protocol.SubscriptionType;
-import org.apache.eventmesh.common.utils.LogUtils;
 import org.apache.eventmesh.common.utils.ThreadUtils;
 import org.apache.eventmesh.grpc.GrpcAbstractDemo;
 
@@ -63,7 +62,7 @@ public class CloudEventsSubscribeReply extends GrpcAbstractDemo implements Recei
 
     @Override
     public Optional<CloudEvent> handle(final CloudEvent msg) {
-        LogUtils.info(log, "receive request-reply msg: {}", msg);
+        log.info("receive request-reply msg: {}", msg);
 
         if (msg != null) {
             return Optional.of(msg);
