@@ -29,7 +29,6 @@ import org.apache.eventmesh.common.ExampleConstants;
 import org.apache.eventmesh.common.enums.EventMeshProtocolType;
 import org.apache.eventmesh.common.protocol.workflow.protos.ExecuteRequest;
 import org.apache.eventmesh.common.protocol.workflow.protos.ExecuteResponse;
-import org.apache.eventmesh.common.utils.LogUtils;
 import org.apache.eventmesh.common.utils.ThreadUtils;
 import org.apache.eventmesh.grpc.GrpcAbstractDemo;
 import org.apache.eventmesh.selector.NacosSelector;
@@ -81,7 +80,7 @@ public class WorkflowOrderAsyncSubscribe extends GrpcAbstractDemo implements Rec
 
     @Override
     public Optional<EventMeshMessage> handle(final EventMeshMessage msg) throws Exception {
-        LogUtils.info(log, "receive async msg: {}", msg);
+        log.info("receive async msg: {}", msg);
 
         final Map<String, String> props = msg.getProp();
         final String workflowInstanceId = props.get("workflowinstanceid");
@@ -91,7 +90,7 @@ public class WorkflowOrderAsyncSubscribe extends GrpcAbstractDemo implements Rec
             .setTaskInstanceId(taskInstanceId)
             .setInstanceId(workflowInstanceId).build();
         final ExecuteResponse response = workflowClient.getWorkflowClient().execute(executeRequest);
-        LogUtils.info(log, "receive workflow msg: {}", response.getInstanceId());
+        log.info("receive workflow msg: {}", response.getInstanceId());
         return Optional.empty();
     }
 
