@@ -18,7 +18,6 @@
 package org.apache.eventmesh.runtime.boot;
 
 import org.apache.eventmesh.common.EventMeshThreadFactory;
-import org.apache.eventmesh.common.utils.LogUtils;
 import org.apache.eventmesh.common.utils.SystemUtils;
 import org.apache.eventmesh.common.utils.ThreadUtils;
 import org.apache.eventmesh.runtime.core.protocol.producer.ProducerManager;
@@ -31,25 +30,35 @@ import io.netty.channel.epoll.EpollEventLoopGroup;
 import io.netty.channel.nio.NioEventLoopGroup;
 import io.netty.util.concurrent.EventExecutorGroup;
 
+import lombok.Getter;
+import lombok.Setter;
 import lombok.extern.slf4j.Slf4j;
 
 /**
  * The most basic server
  */
 @Slf4j
+@Getter
 public abstract class AbstractRemotingServer implements RemotingServer {
 
     private static final int MAX_THREADS = Runtime.getRuntime().availableProcessors();
     private static final int DEFAULT_SLEEP_SECONDS = 30;
 
+    @Setter
     private EventLoopGroup bossGroup;
+
+    @Setter
     private EventLoopGroup ioGroup;
+
+    @Setter
     private EventExecutorGroup workerGroup;
+
     protected ProducerManager producerManager;
 
+    @Setter
     private int port;
 
-    private void buildBossGroup(final String threadPrefix) {
+    protected void buildBossGroup(final String threadPrefix) {
         if (useEpoll()) {
             bossGroup = new EpollEventLoopGroup(1, new EventMeshThreadFactory(threadPrefix + "NettyEpoll-Boss", true));
         } else {
@@ -75,15 +84,10 @@ public abstract class AbstractRemotingServer implements RemotingServer {
         producerManager.init();
     }
 
-    public ProducerManager getProducerManager() {
-        return producerManager;
-    }
-
     public void init(final String threadPrefix) throws Exception {
         buildBossGroup(threadPrefix);
         buildIOGroup(threadPrefix);
         buildWorkerGroup(threadPrefix);
-        initProducerManager();
     }
 
     public void start() throws Exception {
@@ -93,57 +97,26 @@ public abstract class AbstractRemotingServer implements RemotingServer {
     public void shutdown() throws Exception {
         if (bossGroup != null) {
             bossGroup.shutdownGracefully();
-            LogUtils.info(log, "shutdown bossGroup");
+            log.info("shutdown bossGroup");
+        }
+        if (producerManager != null) {
+            producerManager.shutdown();
         }
-        producerManager.shutdown();
 
         ThreadUtils.randomPause(TimeUnit.SECONDS.toMillis(DEFAULT_SLEEP_SECONDS));
 
         if (ioGroup != null) {
             ioGroup.shutdownGracefully();
-            LogUtils.info(log, "shutdown ioGroup");
+            log.info("shutdown ioGroup");
         }
-
         if (workerGroup != null) {
             workerGroup.shutdownGracefully();
 
-            LogUtils.info(log, "shutdown workerGroup");
+            log.info("shutdown workerGroup");
         }
     }
 
     protected boolean useEpoll() {
         return SystemUtils.isLinuxPlatform() && Epoll.isAvailable();
     }
-
-    public EventLoopGroup getBossGroup() {
-        return bossGroup;
-    }
-
-    public void setBossGroup(final EventLoopGroup bossGroup) {
-        this.bossGroup = bossGroup;
-    }
-
-    public EventLoopGroup getIoGroup() {
-        return ioGroup;
-    }
-
-    public void setIoGroup(final EventLoopGroup ioGroup) {
-        this.ioGroup = ioGroup;
-    }
-
-    public EventExecutorGroup getWorkerGroup() {
-        return workerGroup;
-    }
-
-    public void setWorkerGroup(final EventExecutorGroup workerGroup) {
-        this.workerGroup = workerGroup;
-    }
-
-    public int getPort() {
-        return port;
-    }
-
-    public void setPort(final int port) {
-        this.port = port;
-    }
 }
