@@ -23,10 +23,13 @@ import org.apache.eventmesh.common.config.ConfigService;
 import org.apache.eventmesh.common.utils.ConfigurationContextUtil;
 import org.apache.eventmesh.runtime.configuration.EventMeshGrpcConfiguration;
 
+import lombok.Getter;
+
 public class EventMeshGrpcBootstrap implements EventMeshBootstrap {
 
     private final EventMeshGrpcConfiguration eventMeshGrpcConfiguration;
 
+    @Getter
     private EventMeshGrpcServer eventMeshGrpcServer;
 
     private final EventMeshServer eventMeshServer;
@@ -62,12 +65,4 @@ public class EventMeshGrpcBootstrap implements EventMeshBootstrap {
             eventMeshGrpcServer.shutdown();
         }
     }
-
-    public EventMeshGrpcServer getEventMeshGrpcServer() {
-        return eventMeshGrpcServer;
-    }
-
-    public void setEventMeshGrpcServer(EventMeshGrpcServer eventMeshGrpcServer) {
-        this.eventMeshGrpcServer = eventMeshGrpcServer;
-    }
 }
