@@ -36,7 +36,7 @@ import org.apache.eventmesh.runtime.core.protocol.grpc.service.ConsumerService;
 import org.apache.eventmesh.runtime.core.protocol.grpc.service.HeartbeatService;
 import org.apache.eventmesh.runtime.core.protocol.grpc.service.PublisherService;
 import org.apache.eventmesh.runtime.meta.MetaStorage;
-import org.apache.eventmesh.runtime.metrics.grpc.EventMeshGrpcMonitor;
+import org.apache.eventmesh.runtime.metrics.grpc.EventMeshGrpcMetricsManager;
 
 import org.apache.commons.lang3.RandomUtils;
 import org.apache.http.impl.client.CloseableHttpClient;
@@ -92,7 +92,7 @@ public class EventMeshGrpcServer extends AbstractRemotingServer {
 
     private final EventMeshServer eventMeshServer;
 
-    private EventMeshGrpcMonitor eventMeshGrpcMonitor;
+    private EventMeshGrpcMetricsManager eventMeshGrpcMetricsManager;
 
     public EventMeshGrpcServer(final EventMeshServer eventMeshServer, final EventMeshGrpcConfiguration eventMeshGrpcConfiguration) {
         this.eventMeshServer = eventMeshServer;
@@ -147,7 +147,7 @@ public class EventMeshGrpcServer extends AbstractRemotingServer {
             this.register();
         }
 
-        eventMeshGrpcMonitor.start();
+        eventMeshGrpcMetricsManager.start();
         log.info("---------------EventMeshGRPCServer running-------------------");
     }
 
@@ -167,7 +167,7 @@ public class EventMeshGrpcServer extends AbstractRemotingServer {
             this.unRegister();
         }
 
-        eventMeshGrpcMonitor.shutdown();
+        eventMeshGrpcMetricsManager.shutdown();
         log.info("---------------EventMeshGRPCServer stopped-------------------");
     }
 
@@ -237,8 +237,8 @@ public class EventMeshGrpcServer extends AbstractRemotingServer {
         return httpClientPool.get(RandomUtils.nextInt(size, 2 * size) % size);
     }
 
-    public EventMeshGrpcMonitor getMetricsMonitor() {
-        return eventMeshGrpcMonitor;
+    public EventMeshGrpcMetricsManager getEventMeshGrpcMetricsManager() {
+        return eventMeshGrpcMetricsManager;
     }
 
     private void initThreadPool() {
@@ -281,14 +281,13 @@ public class EventMeshGrpcServer extends AbstractRemotingServer {
         }
     }
 
+
+
     private void initMetricsMonitor() throws Exception {
         final List<MetricsRegistry> metricsRegistries = Lists.newArrayList();
-        Optional.ofNullable(eventMeshGrpcConfiguration.getEventMeshMetricsPluginType())
-            .ifPresent(
-                metricsPlugins -> metricsPlugins.forEach(
-                    pluginType -> metricsRegistries.add(MetricsPluginFactory.getMetricsRegistry(pluginType))));
-        eventMeshGrpcMonitor = new EventMeshGrpcMonitor(this, metricsRegistries);
-        eventMeshGrpcMonitor.init();
+        Optional.ofNullable(eventMeshGrpcConfiguration.getEventMeshMetricsPluginType()).ifPresent(
+            metricsPlugins -> metricsPlugins.forEach(pluginType -> metricsRegistries.add(MetricsPluginFactory.getMetricsRegistry(pluginType))));
+        eventMeshGrpcMetricsManager = new EventMeshGrpcMetricsManager(this, metricsRegistries);
     }
 
     private void shutdownThreadPools() {
