@@ -20,7 +20,6 @@ package org.apache.eventmesh.runtime.core.protocol.grpc.consumer.consumergroup;
 import org.apache.eventmesh.common.protocol.SubscriptionMode;
 import org.apache.eventmesh.common.protocol.grpc.cloudevents.CloudEvent;
 import org.apache.eventmesh.common.protocol.grpc.common.GrpcType;
-import org.apache.eventmesh.common.utils.LogUtils;
 import org.apache.eventmesh.runtime.core.protocol.grpc.service.EventEmitter;
 
 import org.apache.commons.collections4.MapUtils;
@@ -63,8 +62,7 @@ public class StreamTopicConfig extends ConsumerGroupTopicConfig {
         Objects.requireNonNull(client, "ConsumerGroupClient can not be null");
 
         if (client.getGrpcType() != grpcType) {
-            LogUtils.warn(log, "Invalid grpc type: {}, expecting grpc type: {}, can not register client {}",
-                client.getGrpcType(), grpcType, client);
+            log.warn("Invalid grpc type: {}, expecting grpc type: {}, can not register client {}", client.getGrpcType(), grpcType, client);
             return;
         }
 
