@@ -25,6 +25,7 @@ import org.apache.eventmesh.common.protocol.tcp.Header;
 import org.apache.eventmesh.common.protocol.tcp.OPStatus;
 import org.apache.eventmesh.common.protocol.tcp.Package;
 import org.apache.eventmesh.common.protocol.tcp.UserAgent;
+import org.apache.eventmesh.common.utils.IPUtils;
 import org.apache.eventmesh.common.utils.JsonUtils;
 import org.apache.eventmesh.runtime.configuration.EventMeshTCPConfiguration;
 import org.apache.eventmesh.runtime.constants.EventMeshConstants;
@@ -188,10 +189,7 @@ public class Session {
                             MESSAGE_LOGGER.error("write2Client fail, pkg[{}] session[{}]", pkg, this);
                         } else {
                             Objects.requireNonNull(clientGroupWrapper.get())
-                                .getEventMeshTcpMonitor()
-                                .getTcpSummaryMetrics()
-                                .getEventMesh2clientMsgNum()
-                                .incrementAndGet();
+                                .getEventMeshTcpMetricsManager().eventMesh2clientMsgNumIncrement(IPUtils.parseChannelRemoteAddr(future.channel()));
                         }
                     }
                 });
@@ -238,15 +236,15 @@ public class Session {
     @Override
     public int hashCode() {
         int result = 1001; // primeNumber
-        if (null != client) {
+        if (client != null) {
             result += 31 * result + Objects.hash(client);
         }
 
-        if (null != context) {
+        if (context != null) {
             result += 31 * result + Objects.hash(context);
         }
 
-        if (null != sessionState) {
+        if (sessionState != null) {
             result += 31 * result + Objects.hash(sessionState);
         }
         return result;
