@@ -141,12 +141,7 @@ public class SessionSender {
                         TraceUtils.finishSpan(span, event);
                     }
                 }
-
-                Objects.requireNonNull(session.getClientGroupWrapper().get())
-                    .getEventMeshTcpMonitor()
-                    .getTcpSummaryMetrics()
-                    .getEventMesh2mqMsgNum()
-                    .incrementAndGet();
+                Objects.requireNonNull(session.getClientGroupWrapper().get()).getEventMeshTcpMetricsManager().eventMesh2mqMsgNumIncrement();
             } else {
                 log.warn("send too fast,session flow control,session:{}", session.getClient());
                 return new EventMeshTcpSendResult(header.getSeq(), EventMeshTcpSendStatus.SEND_TOO_FAST,
@@ -178,9 +173,7 @@ public class SessionSender {
                     .withExtension(EventMeshConstants.RSP_RECEIVE_EVENTMESH_IP,
                         session.getEventMeshTCPConfiguration().getEventMeshServerIp())
                     .build();
-                Objects.requireNonNull(session.getClientGroupWrapper().get())
-                    .getEventMeshTcpMonitor().getTcpSummaryMetrics().getMq2eventMeshMsgNum()
-                    .incrementAndGet();
+                Objects.requireNonNull(session.getClientGroupWrapper().get()).getEventMeshTcpMetricsManager().mq2eventMeshMsgNumIncrement();
 
                 Command cmd;
                 if (Command.REQUEST_TO_SERVER == header.getCmd()) {
