@@ -50,7 +50,6 @@ public class EventMeshGrpcConfigurationTest {
         Assertions.assertEquals(5816, config.getEventMeshServerReplyMsgThreadNum());
         Assertions.assertEquals(6816, config.getEventMeshServerSubscribeMsgThreadNum());
         Assertions.assertEquals(7816, config.getEventMeshServerMetaStorageThreadNum());
-        Assertions.assertEquals(8816, config.getEventMeshServerAdminThreadNum());
         Assertions.assertEquals(9816, config.getEventMeshServerRetryThreadNum());
         Assertions.assertEquals(11816, config.getEventMeshServerPullMetaStorageInterval());
         Assertions.assertEquals(12816, config.getEventMeshServerAsyncAccumulationThreshold());
@@ -72,7 +71,6 @@ public class EventMeshGrpcConfigurationTest {
         Assertions.assertEquals("cluster-succeed!!!", config.getEventMeshCluster());
         Assertions.assertEquals("name-succeed!!!", config.getEventMeshName());
         Assertions.assertEquals("816", config.getSysID());
-        Assertions.assertEquals("connector-succeed!!!", config.getEventMeshConnectorPluginType());
         Assertions.assertEquals("storage-succeed!!!", config.getEventMeshStoragePluginType());
         Assertions.assertEquals("security-succeed!!!", config.getEventMeshSecurityPluginType());
         Assertions.assertEquals("metaStorage-succeed!!!", config.getEventMeshMetaStoragePluginType());
