@@ -20,7 +20,6 @@ package org.apache.eventmesh.runtime.demo;
 import org.apache.eventmesh.common.protocol.SubscriptionMode;
 import org.apache.eventmesh.common.protocol.SubscriptionType;
 import org.apache.eventmesh.common.protocol.tcp.Command;
-import org.apache.eventmesh.common.utils.LogUtils;
 import org.apache.eventmesh.runtime.client.common.MessageUtils;
 import org.apache.eventmesh.runtime.client.impl.EventMeshClientImpl;
 
@@ -44,7 +43,7 @@ public class CClientDemo {
         client.listen();
         client.registerSubBusiHandler((msg, ctx) -> {
             if (msg.getHeader().getCmd() == Command.ASYNC_MESSAGE_TO_CLIENT || msg.getHeader().getCmd() == Command.BROADCAST_MESSAGE_TO_CLIENT) {
-                LogUtils.info(log, "receive message: {}", msg);
+                log.info("receive message: {}", msg);
             }
         });
         for (int i = 0; i < 10000; i++) {
