@@ -42,7 +42,6 @@ import org.apache.eventmesh.common.protocol.grpc.common.ProtocolKey;
 import org.apache.eventmesh.common.protocol.grpc.common.Response;
 import org.apache.eventmesh.common.protocol.grpc.common.StatusCode;
 import org.apache.eventmesh.common.utils.JsonUtils;
-import org.apache.eventmesh.common.utils.LogUtils;
 
 import org.apache.commons.collections4.MapUtils;
 
@@ -88,8 +87,7 @@ public class EventMeshGrpcConsumer implements AutoCloseable {
     }
 
     public void init() {
-        this.channel = ManagedChannelBuilder.forAddress(clientConfig.getServerAddr(), clientConfig.getServerPort()).usePlaintext()
-            .build();
+        this.channel = ManagedChannelBuilder.forAddress(clientConfig.getServerAddr(), clientConfig.getServerPort()).usePlaintext().build();
         this.consumerClient = ConsumerServiceGrpc.newBlockingStub(channel);
         this.consumerAsyncClient = ConsumerServiceGrpc.newStub(channel);
         this.heartbeatClient = HeartbeatServiceGrpc.newBlockingStub(channel);
@@ -104,7 +102,7 @@ public class EventMeshGrpcConsumer implements AutoCloseable {
      * @return A response containing information about the subscription result.
      */
     public Response subscribe(final List<SubscriptionItem> subscriptionItems, final String url) {
-        LogUtils.info(log, "Create subscription: {} , url: {}", subscriptionItems, url);
+        log.info("Create subscription: {} , url: {}", subscriptionItems, url);
 
         addSubscription(subscriptionItems, url, GrpcType.WEBHOOK);
 
@@ -117,7 +115,7 @@ public class EventMeshGrpcConsumer implements AutoCloseable {
      * @param subscriptionItems The list of subscription items for streaming.
      */
     public void subscribe(final List<SubscriptionItem> subscriptionItems) {
-        LogUtils.info(log, "Create streaming subscription: {}", subscriptionItems);
+        log.info("Create streaming subscription: {}", subscriptionItems);
 
         if (listener == null) {
             log.error("Error in subscriber, no Event Listener is registered.");
@@ -126,8 +124,8 @@ public class EventMeshGrpcConsumer implements AutoCloseable {
 
         addSubscription(subscriptionItems, SDK_STREAM_URL, GrpcType.STREAM);
 
-        CloudEvent subscription = EventMeshCloudEventBuilder.buildEventSubscription(clientConfig, EventMeshProtocolType.EVENT_MESH_MESSAGE, null,
-            subscriptionItems);
+        CloudEvent subscription = EventMeshCloudEventBuilder.buildEventSubscription(
+            clientConfig, EventMeshProtocolType.EVENT_MESH_MESSAGE, null, subscriptionItems);
         synchronized (this) {
             if (subStreamHandler == null) {
                 subStreamHandler = new SubStreamHandler<>(consumerAsyncClient, clientConfig, listener);
@@ -138,11 +136,11 @@ public class EventMeshGrpcConsumer implements AutoCloseable {
     }
 
     private Response subscribeWebhook(List<SubscriptionItem> subscriptionItems, String url) {
-        final CloudEvent subscription = EventMeshCloudEventBuilder.buildEventSubscription(clientConfig, EventMeshProtocolType.EVENT_MESH_MESSAGE,
-            url, subscriptionItems);
+        final CloudEvent subscription = EventMeshCloudEventBuilder.buildEventSubscription(
+            clientConfig, EventMeshProtocolType.EVENT_MESH_MESSAGE, url, subscriptionItems);
         try {
             CloudEvent response = consumerClient.subscribe(subscription);
-            LogUtils.info(log, "Received response:{}", response);
+            log.info("Received response:{}", response);
             return Response.builder()
                 .respCode(EventMeshCloudEventUtils.getResponseCode(response))
                 .respMsg(EventMeshCloudEventUtils.getResponseMessage(response))
@@ -166,15 +164,15 @@ public class EventMeshGrpcConsumer implements AutoCloseable {
     }
 
     public Response unsubscribe(final List<SubscriptionItem> subscriptionItems, final String url) {
-        LogUtils.info(log, "Removing subscription: {}, url:{}", subscriptionItems, url);
+        log.info("Removing subscription: {}, url:{}", subscriptionItems, url);
 
         removeSubscription(subscriptionItems);
 
-        final CloudEvent cloudEvent = EventMeshCloudEventBuilder.buildEventSubscription(clientConfig, EventMeshProtocolType.EVENT_MESH_MESSAGE, url,
-            subscriptionItems);
+        final CloudEvent cloudEvent = EventMeshCloudEventBuilder.buildEventSubscription(
+            clientConfig, EventMeshProtocolType.EVENT_MESH_MESSAGE, url, subscriptionItems);
         try {
             final CloudEvent response = consumerClient.unsubscribe(cloudEvent);
-            LogUtils.info(log, "Received response:{}", response);
+            log.info("Received response:{}", response);
             return Response.builder()
                 .respCode(EventMeshCloudEventUtils.getResponseCode(response))
                 .respMsg(EventMeshCloudEventUtils.getResponseMessage(response))
@@ -188,12 +186,12 @@ public class EventMeshGrpcConsumer implements AutoCloseable {
 
     public Response unsubscribe(final List<SubscriptionItem> subscriptionItems) {
         Objects.requireNonNull(subscriptionItems, "subscriptionItems can not be null");
-        LogUtils.info(log, "Removing subscription stream: {}", subscriptionItems);
+        log.info("Removing subscription stream: {}", subscriptionItems);
 
         removeSubscription(subscriptionItems);
 
-        final CloudEvent cloudEvent = EventMeshCloudEventBuilder.buildEventSubscription(clientConfig, EventMeshProtocolType.EVENT_MESH_MESSAGE, null,
-            subscriptionItems);
+        final CloudEvent cloudEvent = EventMeshCloudEventBuilder.buildEventSubscription(
+            clientConfig, EventMeshProtocolType.EVENT_MESH_MESSAGE, null, subscriptionItems);
 
         try {
             final CloudEvent response = consumerClient.unsubscribe(cloudEvent);
@@ -202,7 +200,7 @@ public class EventMeshGrpcConsumer implements AutoCloseable {
                 .respMsg(EventMeshCloudEventUtils.getResponseMessage(response))
                 .respTime(EventMeshCloudEventUtils.getResponseTime(response))
                 .build();
-            LogUtils.info(log, "Received response:{}", parsedResponse);
+            log.info("Received response:{}", parsedResponse);
 
             // there is no stream subscriptions, stop the subscription stream handler
             synchronized (this) {
@@ -249,7 +247,7 @@ public class EventMeshGrpcConsumer implements AutoCloseable {
                     .respMsg(EventMeshCloudEventUtils.getResponseMessage(cloudEventResp))
                     .respTime(EventMeshCloudEventUtils.getResponseTime(cloudEventResp))
                     .build();
-                LogUtils.debug(log, "Grpc Consumer Heartbeat cloudEvent: {}", response);
+                log.debug("Grpc Consumer Heartbeat cloudEvent: {}", response);
                 if (StatusCode.CLIENT_RESUBSCRIBE.getRetCode().equals(response.getRespCode())) {
                     resubscribe();
                 }
@@ -258,7 +256,7 @@ public class EventMeshGrpcConsumer implements AutoCloseable {
             }
         }, 10_000, EventMeshCommon.HEARTBEAT, TimeUnit.MILLISECONDS);
 
-        LogUtils.info(log, "Grpc Consumer Heartbeat started.");
+        log.info("Grpc Consumer Heartbeat started.");
     }
 
     private void resubscribe() {
@@ -278,14 +276,12 @@ public class EventMeshGrpcConsumer implements AutoCloseable {
 
         subscriptionGroup.forEach((url, items) -> {
             if (isStreamSub.get()) {
-                CloudEvent subscription = EventMeshCloudEventBuilder.buildEventSubscription(clientConfig, EventMeshProtocolType.EVENT_MESH_MESSAGE,
-                    url,
-                    items);
+                CloudEvent subscription = EventMeshCloudEventBuilder.buildEventSubscription(
+                    clientConfig, EventMeshProtocolType.EVENT_MESH_MESSAGE, url, items);
                 subStreamHandler.sendSubscription(subscription);
             } else {
                 subscribeWebhook(items, url);
             }
-
         });
     }
 
@@ -304,6 +300,7 @@ public class EventMeshGrpcConsumer implements AutoCloseable {
         }
     }
 
+    @Data
     private static class SubscriptionInfo {
 
         private transient SubscriptionItem subscriptionItem;
@@ -315,25 +312,5 @@ public class EventMeshGrpcConsumer implements AutoCloseable {
             this.url = url;
             this.grpcType = grpcType;
         }
-
-        public GrpcType getGrpcType() {
-            return grpcType;
-        }
-
-        public SubscriptionItem getSubscriptionItem() {
-            return subscriptionItem;
-        }
-
-        public void setSubscriptionItem(final SubscriptionItem subscriptionItem) {
-            this.subscriptionItem = subscriptionItem;
-        }
-
-        public String getUrl() {
-            return url;
-        }
-
-        public void setUrl(final String url) {
-            this.url = url;
-        }
     }
 }
