@@ -23,7 +23,6 @@ import org.apache.eventmesh.common.ThreadPoolFactory;
 import org.apache.eventmesh.common.protocol.tcp.Package;
 import org.apache.eventmesh.common.protocol.tcp.UserAgent;
 import org.apache.eventmesh.common.protocol.tcp.codec.Codec;
-import org.apache.eventmesh.common.utils.LogUtils;
 
 import java.io.Closeable;
 import java.net.InetSocketAddress;
@@ -61,7 +60,7 @@ import lombok.extern.slf4j.Slf4j;
 @Slf4j
 public abstract class TcpClient implements Closeable {
 
-    protected static transient int CLIENTNO = 0;
+    protected static int CLIENTNO = 0;
 
     static {
         try {
@@ -118,23 +117,24 @@ public abstract class TcpClient implements Closeable {
         ChannelFuture f = bootstrap.connect(host, port).sync();
         InetSocketAddress localAddress = (InetSocketAddress) f.channel().localAddress();
         channel = f.channel();
-        LogUtils.info(log, "connected|local={}:{}|server={}", localAddress.getAddress().getHostAddress(),
-            localAddress.getPort(), host + ":" + port);
+        log.info("connected|local={}:{}|server={}", localAddress.getAddress().getHostAddress(), localAddress.getPort(), host + ":" + port);
     }
 
     @Override
     public void close() {
         try {
+
+            goodbye();
+
             channel.disconnect().sync();
-            workers.shutdownGracefully();
+            workers.shutdownGracefully().sync();
             if (heartTask != null) {
                 heartTask.cancel(false);
             }
-            goodbye();
+
         } catch (Exception e) {
             Thread.currentThread().interrupt();
-
-            LogUtils.warn(log, "close tcp client failed.|remote address={}", channel.remoteAddress(), e);
+            log.warn("close tcp client failed.|remote address={}", channel.remoteAddress(), e);
         }
     }
 
@@ -148,7 +148,7 @@ public abstract class TcpClient implements Closeable {
                         }
                         Package msg = MessageUtils.heartBeat();
                         io(msg, EventMeshCommon.DEFAULT_TIME_OUT_MILLS);
-                        LogUtils.debug(log, "heart beat start {}", msg);
+                        log.debug("heart beat start {}", msg);
                     } catch (Exception e) {
                         // ignore
                     }
@@ -170,7 +170,7 @@ public abstract class TcpClient implements Closeable {
         if (channel.isWritable()) {
             channel.writeAndFlush(msg).addListener((ChannelFutureListener) future -> {
                 if (!future.isSuccess()) {
-                    LogUtils.warn(log, "send msg failed", future.cause());
+                    log.warn("send msg failed", future.cause());
                 }
             });
         } else {
@@ -181,10 +181,9 @@ public abstract class TcpClient implements Closeable {
     protected Package io(Package msg, long timeout) throws Exception {
         Object key = RequestContext.key(msg);
         RequestContext context = RequestContext.context(key, msg);
-        if (!contexts.containsValue(context)) {
-            contexts.put(key, context);
-        } else {
-            LogUtils.info(log, "duplicate key : {}", key);
+        RequestContext previousContext = contexts.putIfAbsent(key, context);
+        if (previousContext != null) {
+            log.info("duplicate key : {}", key);
         }
         send(msg);
         Supplier<Package> supplier = () -> {
@@ -214,8 +213,7 @@ public abstract class TcpClient implements Closeable {
 
             @Override
             public void exceptionCaught(ChannelHandlerContext ctx, Throwable cause) {
-                LogUtils.info(log, "exceptionCaught, close connection.|remote address={}",
-                    ctx.channel().remoteAddress(), cause);
+                log.info("exceptionCaught, close connection.|remote address={}", ctx.channel().remoteAddress(), cause);
                 ctx.close();
             }
         };
