@@ -72,7 +72,7 @@ public class PushConsumerImpl {
         }
         this.rocketmqPushConsumer.setNamesrvAddr(accessPoints.replace(',', ';'));
         String consumerGroup = clientConfig.getConsumerId();
-        if (null == consumerGroup || consumerGroup.isEmpty()) {
+        if (consumerGroup == null || consumerGroup.isEmpty()) {
             throw new StorageRuntimeException(
                 "Consumer Group is necessary for RocketMQ, please set it.");
         }
