@@ -441,7 +441,7 @@ public class ConsumeMessageConcurrentlyService implements ConsumeMessageService
                 hasException = true;
             }
             long consumeRT = System.currentTimeMillis() - beginTimestamp;
-            if (null == status) {
+            if (status == null) {
                 if (hasException) {
                     returnType = ConsumeReturnType.EXCEPTION;
                 } else {
@@ -457,7 +457,7 @@ public class ConsumeMessageConcurrentlyService implements ConsumeMessageService
                 Objects.requireNonNull(consumeMessageContext).getProps().put(MixAll.CONSUME_CONTEXT_TYPE, returnType.name());
             }
 
-            if (null == status) {
+            if (status == null) {
                 log.warn("consumeMessage return null, Group: {} Msgs: {} MQ: {}",
                     ConsumeMessageConcurrentlyService.this.consumerGroup,
                     msgs,
