@@ -236,10 +236,11 @@ public class MessageQueue {
      * @return The MessageEntity object at the head of the queue.
      */
     private MessageEntity dequeue() {
-        MessageEntity item = items[takeIndex++];
+        final MessageEntity item = items[takeIndex++];
         if (takeIndex == items.length) {
             takeIndex = 0;
         }
+        count--;
         notFull.signalAll();
         return item;
     }
