@@ -20,17 +20,12 @@ package org.apache.eventmesh.storage.standalone.consumer;
 import org.apache.eventmesh.api.AbstractContext;
 import org.apache.eventmesh.api.EventListener;
 import org.apache.eventmesh.api.consumer.Consumer;
-import org.apache.eventmesh.common.ThreadPoolFactory;
 import org.apache.eventmesh.storage.standalone.broker.StandaloneBroker;
-import org.apache.eventmesh.storage.standalone.broker.model.TopicMetadata;
 import org.apache.eventmesh.storage.standalone.broker.task.Subscribe;
-import org.apache.eventmesh.storage.standalone.broker.task.SubscribeTask;
 
 import java.util.List;
-import java.util.Objects;
 import java.util.Properties;
 import java.util.concurrent.ConcurrentHashMap;
-import java.util.concurrent.ExecutorService;
 import java.util.concurrent.atomic.AtomicBoolean;
 
 import io.cloudevents.CloudEvent;
@@ -45,16 +40,10 @@ public class StandaloneConsumer implements Consumer {
 
     private final ConcurrentHashMap<String, Subscribe> subscribeTable;
 
-    private final ExecutorService consumeExecutorService;
-
     public StandaloneConsumer(Properties properties) {
         this.standaloneBroker = StandaloneBroker.getInstance();
         this.subscribeTable = new ConcurrentHashMap<>(16);
         this.isStarted = new AtomicBoolean(false);
-        this.consumeExecutorService = ThreadPoolFactory.createThreadPoolExecutor(
-            Runtime.getRuntime().availableProcessors() * 2,
-            Runtime.getRuntime().availableProcessors() * 2,
-            "StandaloneConsumerThread");
     }
 
     @Override
@@ -86,8 +75,6 @@ public class StandaloneConsumer implements Consumer {
 
     @Override
     public void updateOffset(List<CloudEvent> cloudEvents, AbstractContext context) {
-        cloudEvents.forEach(cloudEvent -> standaloneBroker.updateOffset(
-            new TopicMetadata(cloudEvent.getSubject()), Objects.requireNonNull((Long) cloudEvent.getExtension("offset"))));
 
     }
 
@@ -99,9 +86,8 @@ public class StandaloneConsumer implements Consumer {
         synchronized (subscribeTable) {
             standaloneBroker.createTopicIfAbsent(topic);
             Subscribe subscribe = new Subscribe(topic, standaloneBroker, listener);
-            SubscribeTask subScribeTask = new SubscribeTask(subscribe);
+            subscribe.subscribe();
             subscribeTable.put(topic, subscribe);
-            consumeExecutorService.execute(subScribeTask);
         }
     }
 
