@@ -17,33 +17,43 @@
 
 package org.apache.eventmesh.storage.standalone;
 
+import org.apache.eventmesh.storage.standalone.broker.Channel;
 import org.apache.eventmesh.storage.standalone.broker.MessageQueue;
+import org.apache.eventmesh.storage.standalone.broker.StandaloneBroker;
 import org.apache.eventmesh.storage.standalone.broker.model.MessageEntity;
 import org.apache.eventmesh.storage.standalone.broker.model.TopicMetadata;
+import org.apache.eventmesh.storage.standalone.broker.task.Subscribe;
+
+import org.apache.commons.lang3.tuple.Pair;
 
 import java.net.URI;
-import java.util.Arrays;
+import java.util.Collections;
 import java.util.List;
 import java.util.concurrent.ConcurrentHashMap;
 
 import io.cloudevents.CloudEvent;
 import io.cloudevents.core.builder.CloudEventBuilder;
 
+
 public class TestUtils {
 
     public static final String TEST_TOPIC = "test-topic";
     public static final int OFF_SET = 0;
     public static final int LENGTH = 5;
     public static final int EXCEEDED_MESSAGE_STORE_WINDOW = 60 * 60 * 1000 + 1000;
-    public static final boolean TOPIC_EXISTS = true;
-    public static final boolean TOPIC_DO_NOT_EXISTS = false;
 
-    public static ConcurrentHashMap<TopicMetadata, MessageQueue> createDefaultMessageContainer() {
-        ConcurrentHashMap<TopicMetadata, MessageQueue> messageContainer = new ConcurrentHashMap<>(1);
-        messageContainer.put(new TopicMetadata(TEST_TOPIC), new MessageQueue());
-        return messageContainer;
+    public static Pair<ConcurrentHashMap<TopicMetadata, Channel>, ConcurrentHashMap<TopicMetadata, Subscribe>> createDefaultMessageContainer(
+        StandaloneBroker broker) {
+        ConcurrentHashMap<TopicMetadata, Channel> messageContainer = new ConcurrentHashMap<>(1);
+        ConcurrentHashMap<TopicMetadata, Subscribe> subscribeContainer = new ConcurrentHashMap<>(1);
+
+        Subscribe subscribe = createSubscribe(broker);
+        subscribe.subscribe();
+        subscribeContainer.put(new TopicMetadata(TEST_TOPIC), subscribe);
+        return Pair.of(messageContainer, subscribeContainer);
     }
 
+
     public static ConcurrentHashMap<TopicMetadata, MessageQueue> createMessageContainer(TopicMetadata topicMetadata, MessageEntity messageEntity)
         throws InterruptedException {
         ConcurrentHashMap<TopicMetadata, MessageQueue> messageContainer = new ConcurrentHashMap<>(1);
@@ -63,7 +73,7 @@ public class TestUtils {
     }
 
     public static List<CloudEvent> createCloudEvents() {
-        return Arrays.asList(createDefaultCloudEvent());
+        return Collections.singletonList(createDefaultCloudEvent());
     }
 
     public static MessageEntity createDefaultMessageEntity() {
@@ -81,4 +91,17 @@ public class TestUtils {
             offSet,
             currentTimeMillis);
     }
+
+    public static Subscribe createSubscribe(StandaloneBroker standaloneBroker) {
+        standaloneBroker.createTopic(TEST_TOPIC);
+        return new Subscribe(TEST_TOPIC, standaloneBroker, (cloudEvent, context) -> {
+        });
+    }
+
+    public static Subscribe createSubscribe(StandaloneBroker standaloneBroker, List<CloudEvent> cloudEvents) {
+        standaloneBroker.createTopic(TEST_TOPIC);
+        return new Subscribe(TEST_TOPIC, standaloneBroker, (cloudEvent, context) -> {
+            cloudEvents.add(cloudEvent);
+        });
+    }
 }
