@@ -17,19 +17,20 @@
 
 package org.apache.eventmesh.storage.standalone.admin;
 
-import static org.apache.eventmesh.storage.standalone.TestUtils.LENGTH;
-import static org.apache.eventmesh.storage.standalone.TestUtils.OFF_SET;
 import static org.apache.eventmesh.storage.standalone.TestUtils.TEST_TOPIC;
-import static org.apache.eventmesh.storage.standalone.TestUtils.TOPIC_DO_NOT_EXISTS;
-import static org.apache.eventmesh.storage.standalone.TestUtils.TOPIC_EXISTS;
 import static org.apache.eventmesh.storage.standalone.TestUtils.createDefaultCloudEvent;
 import static org.apache.eventmesh.storage.standalone.TestUtils.createDefaultMessageContainer;
 import static org.apache.eventmesh.storage.standalone.TestUtils.createDefaultMessageEntity;
 
+import org.apache.eventmesh.storage.standalone.broker.Channel;
 import org.apache.eventmesh.storage.standalone.broker.StandaloneBroker;
 import org.apache.eventmesh.storage.standalone.broker.model.MessageEntity;
+import org.apache.eventmesh.storage.standalone.broker.model.TopicMetadata;
+import org.apache.eventmesh.storage.standalone.broker.task.Subscribe;
 
-import java.util.List;
+import org.apache.commons.lang3.tuple.Pair;
+
+import java.util.concurrent.ConcurrentHashMap;
 
 import org.junit.jupiter.api.Assertions;
 import org.junit.jupiter.api.BeforeEach;
@@ -53,6 +54,7 @@ public class StandaloneAdminTest {
 
     private StandaloneAdmin standaloneAdmin;
 
+
     @BeforeEach
     public void setUp() {
         initStaticInstance();
@@ -70,12 +72,6 @@ public class StandaloneAdminTest {
         Assertions.assertTrue(standaloneAdmin.isClosed());
     }
 
-    @Test
-    public void testGetTopic() throws Exception {
-        Assertions.assertNotNull(standaloneAdmin.getTopic());
-        Assertions.assertFalse(standaloneAdmin.getTopic().isEmpty());
-    }
-
     @Test
     public void testCreateTopic() {
         standaloneAdmin.createTopic(TEST_TOPIC);
@@ -88,21 +84,6 @@ public class StandaloneAdminTest {
         Mockito.verify(standaloneBroker).deleteTopicIfExist(TEST_TOPIC);
     }
 
-    @Test
-    public void testGetEvent() throws Exception {
-        Mockito.when(standaloneBroker.checkTopicExist(TEST_TOPIC)).thenReturn(TOPIC_EXISTS);
-        Mockito.when(standaloneBroker.getMessage(TEST_TOPIC, OFF_SET)).thenReturn(createDefaultCloudEvent());
-        List<CloudEvent> events = standaloneAdmin.getEvent(TEST_TOPIC, OFF_SET, LENGTH);
-        Assertions.assertNotNull(events);
-        Assertions.assertFalse(events.isEmpty());
-    }
-
-    @Test
-    public void testGetEvent_throwException() {
-        Mockito.when(standaloneBroker.checkTopicExist(TEST_TOPIC)).thenReturn(TOPIC_DO_NOT_EXISTS);
-        Exception exception = Assertions.assertThrows(Exception.class, () -> standaloneAdmin.getEvent(TEST_TOPIC, OFF_SET, LENGTH));
-        Assertions.assertEquals("The topic name doesn't exist in the message queue", exception.getMessage());
-    }
 
     @Test
     public void testPublish() throws Exception {
@@ -116,7 +97,11 @@ public class StandaloneAdminTest {
     private void initStaticInstance() {
         try (MockedStatic<StandaloneBroker> standaloneBrokerMockedStatic = Mockito.mockStatic(StandaloneBroker.class)) {
             standaloneBrokerMockedStatic.when(StandaloneBroker::getInstance).thenReturn(standaloneBroker);
-            Mockito.when(standaloneBroker.getMessageContainer()).thenReturn(createDefaultMessageContainer());
+            Pair<ConcurrentHashMap<TopicMetadata, Channel>, ConcurrentHashMap<TopicMetadata, Subscribe>> pair =
+                createDefaultMessageContainer(standaloneBroker);
+            Mockito.when(standaloneBroker.getSubscribeContainer()).thenReturn(pair.getRight());
+            Mockito.when(standaloneBroker.getMessageContainer()).thenReturn(pair.getLeft());
+
             standaloneAdmin = new StandaloneAdmin();
         }
     }
