@@ -18,14 +18,11 @@
 package org.apache.eventmesh.storage.standalone.broker.task;
 
 import static org.apache.eventmesh.storage.standalone.TestUtils.TEST_TOPIC;
-import static org.apache.eventmesh.storage.standalone.TestUtils.createDefaultCloudEvent;
 
 import static org.mockito.ArgumentMatchers.any;
-import static org.mockito.ArgumentMatchers.anyLong;
 import static org.mockito.ArgumentMatchers.anyString;
 
 import org.apache.eventmesh.api.EventListener;
-import org.apache.eventmesh.api.EventMeshAsyncConsumeContext;
 import org.apache.eventmesh.storage.standalone.broker.StandaloneBroker;
 
 import org.junit.jupiter.api.Assertions;
@@ -35,8 +32,6 @@ import org.mockito.Mock;
 import org.mockito.Mockito;
 import org.mockito.junit.jupiter.MockitoExtension;
 
-import io.cloudevents.CloudEvent;
-
 @ExtendWith(MockitoExtension.class)
 public class SubscribeTest {
 
@@ -48,12 +43,9 @@ public class SubscribeTest {
 
     @Test
     public void testSubscribe() {
-        CloudEvent cloudEvent = createDefaultCloudEvent();
-        Mockito.when(standaloneBroker.getMessage(anyString())).thenReturn(cloudEvent);
-        Mockito.when(standaloneBroker.getMessage(anyString(), anyLong())).thenReturn(cloudEvent);
         subscribe = new Subscribe(TEST_TOPIC, standaloneBroker, eventListener);
         subscribe.subscribe();
-        Mockito.verify(eventListener).consume(any(CloudEvent.class), any(EventMeshAsyncConsumeContext.class));
+        Mockito.verify(standaloneBroker).subscribed(anyString(), any(Subscribe.class));
     }
 
     @Test
