@@ -21,7 +21,6 @@ import static org.apache.eventmesh.webhook.api.WebHookOperationConstant.OPERATIO
 import static org.apache.eventmesh.webhook.api.WebHookOperationConstant.OPERATION_MODE_NACOS;
 
 import org.apache.eventmesh.common.config.ConfigService;
-import org.apache.eventmesh.common.utils.LogUtils;
 import org.apache.eventmesh.webhook.api.WebHookConfigOperation;
 import org.apache.eventmesh.webhook.config.AdminConfiguration;
 
@@ -73,7 +72,7 @@ public class AdminWebHookConfigOperationManager {
             constructor.setAccessible(true);
             final Properties operationProperties = adminConfiguration.getOperationProperties();
 
-            LogUtils.info(log, "operationMode is {}  properties is {} ", operationMode, operationProperties);
+            log.info("operationMode is {}  properties is {} ", operationMode, operationProperties);
             this.webHookConfigOperation = constructor.newInstance(operationProperties);
         } finally {
             // Restore the original accessibility of constructor
