@@ -23,7 +23,7 @@ import org.apache.eventmesh.api.exception.OnExceptionContext;
 import org.apache.eventmesh.common.config.ConfigService;
 import org.apache.eventmesh.common.protocol.ProtocolTransportObject;
 import org.apache.eventmesh.common.protocol.http.WebhookProtocolTransportObject;
-import org.apache.eventmesh.common.utils.LogUtils;
+import org.apache.eventmesh.common.utils.LogUtil;
 import org.apache.eventmesh.protocol.api.ProtocolAdaptor;
 import org.apache.eventmesh.protocol.api.ProtocolPluginFactory;
 import org.apache.eventmesh.webhook.api.WebHookConfig;
@@ -123,12 +123,12 @@ public class WebHookController {
 
             @Override
             public void onSuccess(SendResult sendResult) {
-                LogUtils.debug(log, sendResult.toString());
+                LogUtil.debug(log, "{}", sendResult::toString);
             }
 
             @Override
             public void onException(OnExceptionContext context) {
-                LogUtils.warn(log, "", context.getException());
+                log.warn("", context.getException());
             }
 
         });
